@@ -32,15 +32,31 @@ class BatchProcessor:
         self.last_status_time = None
         self.callables = {}
         self.entry_name = "batch_filter_entrypoint"
-        logger.info("Available modules:")
-        for (name, error) in self.list_modules():
-            if error:
-                logger.error(f" + '{name}': '{error}'")
-            else:
-                logger.info(f" + '{name}': OK")
-            
         self.db = Database(self.config)
 
+    def verify(self):
+        modules=self.list_modules()
+        ok=[]
+        failed=[]
+        for (name, error) in modules:
+            if error:
+                failed.append((name, error))
+            else:
+                ok.append(name)
+        if ok:
+            logger.info("Available modules:")
+            for name in ok:
+                logger.info(f" + '{name}'")
+        if failed:
+            message=""
+            logger.info("Failed modules:")
+            for (name, error) in failed:
+                logger.error(f" + '{name}': {error}")
+                message += f"{name}: {error}\n"
+            return False, message
+        return True, ""
+
+
     def load_module_by_filepath(self, module_name, module_filepath):
         module = None
         failure = None
@@ -82,13 +98,19 @@ class BatchProcessor:
 
     def list_modules(self):
         module_root_dir=self.config.get("batch-filter-root", "/tmp/inexistant")
-        ret=[("lol", "bob")]
+        ret=[]
         failure=None
-        if os.path.exists(module_root_dir):
+        if not module_root_dir:
+            ret.append(("module_root_dir", f"Module root was not set"))
+        elif not os.path.exists(module_root_dir):
+            ret.append(("module_root_dir", f"Module root '{module_root_dir}' did not exist"))
+        else:
             module_glob = os.path.join(module_root_dir, "**/*.py")
             files=glob.glob(module_glob, recursive = True)
             for module_filepath in files:
-                if module_filepath.startswith("__"):
+                if not module_filepath:
+                    continue
+                if os.path.basename(module_filepath).startswith("__"):
                     continue
                 if fk.utils.file_contains_str(module_filepath, self.entry_name):
                     try:
@@ -107,10 +129,8 @@ class BatchProcessor:
                         failure = f"Import of module '{module_filepath}' had errors and was skipped ({e})"
                 else:
                     failure = f"No entrypoint found in filter module {module_filepath}"
-                ret.append({module_filepath, failure})
-        else:
-            failure = f"Module filterpath did not exist '{module_filepath}'"
-            ret.append((module_root_dir, failure))
+                #logger.warn(f"Appending stat: {module_filepath}:{failure}")
+                ret.append((module_filepath, failure))
         return ret
 
     def get_callable_for_type_raw(self, type):
